import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.Reader;
import java.util.HashSet;
import java.util.PriorityQueue;
import java.util.StringTokenizer;
import java.util.TreeSet;

public class TaskF {
	
	public static void main(String[] args) throws Exception {
		Tokenizer in = new Tokenizer(new InputStreamReader(System.in));
		
		int n = in.nextInt();
		Vertex[] vertices = new Vertex[n];
		for(int i = 0; i < n; i++) vertices[i] = new Vertex(i);
		
		for(int i = 0; i < n - 1; i++) {
			int u = in.nextInt() - 1, v = in.nextInt() - 1;
			long l = in.nextLong();
			
			Edge e = new Edge(l, vertices[u], vertices[v]);
			vertices[u].add(e);
			vertices[v].add(e);
		}
		
		PriorityQueue<Pair> queue = new PriorityQueue<>();
		
		int m = in.nextInt();
		for(int i = 0; i < m; i++) {
			int u = in.nextInt() - 1;
			Edge e = new Edge(0, vertices[u], null);
			
			vertices[u].add(e);
			queue.add(new Pair(0, e));
		}
		
		int components = 1;
		int maximum = 1;

		long lastTime = 0;
		while(!queue.isEmpty()) {
			long time = queue.peek().value;
			if(time != lastTime) maximum = Math.max(maximum, components);
			
			Edge e = queue.poll().edge;
			if(!e.active) continue;
			
			if(!isActiveV(e.a) && !isActiveV(e.b)) {
				//System.out.println("----");
				components--;
			} else {
				Vertex target = isActiveV(e.a) ? e.a : e.b;
				//System.out.println("Target: " + (target.number + 1));
				
				target.active = false;
				target.remove(e);
				components += target.size() - 1;
				
				for(Edge ee : target) 
					if(ee.active) queue.add(new Pair(time + ee.length, ee));
			}
			e.active = false;

			//System.out.println(getNumber(e.a) + " -- " + getNumber(e.b) + " | " + components);
		}
		
		System.out.println(maximum);
	}
	
	private static String getNumber(Vertex v) {
		if(v == null) return "F";
		return (v.number + 1) + "";
	}
	
	private static boolean isActiveV(Vertex v) {
		return v != null && v.active;
	}
	
	private static class Edge {
		
		public long length;
		public Vertex a, b;
		
		public boolean active = true;
		
		public Edge(long l, Vertex _a, Vertex _b) {
			length = l; a = _a; b = _b;
		}
		
	}
	
	private static class Vertex extends HashSet<Edge> {
		
		public final int number;
		public boolean active = true;
		
		public Vertex(int i) {
			number = i;
		}
		
	}
	
	private static class Pair implements Comparable<Pair> {
		
		public long value;
		public Edge edge;
		
		public Pair(long v, Edge e) {
			value = v; edge = e;
		}
		
		@Override
		public int compareTo(Pair o) {
			return Long.compare(value, o.value);
		}
		
	}
	
	private static class Tokenizer {

		private final BufferedReader in;
		private StringTokenizer tokenizer = null;

		public Tokenizer(Reader reader) {
			in = new BufferedReader(reader);
		}

		public String next() throws Exception {
			while(tokenizer == null || !tokenizer.hasMoreElements())
				tokenizer = new StringTokenizer(in.readLine());
			return tokenizer.nextToken();
		}

		public int nextInt() throws Exception {
			return Integer.parseInt(next());
		}

		public long nextLong() throws Exception {
			return Long.parseLong(next());
		}

		public double nextDouble() throws Exception {
			return Double.parseDouble(next());
		}

	}
	
}
