#include <iostream>
#include <cstdint>
#include <iterator>
#include <utility>
#include <algorithm>
#include <string>
#include <vector>
#include <unordered_map>

using namespace std;

struct Scope {
	unordered_map<string, int64_t> data;
	Scope* parent;

	Scope() : data(), parent(nullptr) {

	}

	explicit Scope(Scope* parent) : data(), parent(parent) {

	}

	int64_t get(const string& key) const {
		const auto& it = data.find(key);
		if (it == data.end())
			if (parent != nullptr)
				return parent->get(key);
			else
				return 0;
		return it->second;
	}
};

int main()
{
	ios::sync_with_stdio(false);
	string line;
	Scope* root = new Scope();
	Scope* cur = root;
	while (getline(cin, line)) {
		if (line[0] == '{') {
			cur = new Scope(cur);
		}
		else if (line[0] == '}') {
			auto* v = cur;
			cur = v->parent;
			delete v;
		}
		else {
			auto it = line.find('=');
			string name = line.substr(0, it);
			it++;
			if (isdigit(line[it]) || ((line[it] == '-') && isdigit(line[it + 1]))) {
				const auto v = atoll(line.c_str() + it);
				cur->data[name] = v;
			}
			else {
				const auto& ref = line.substr(it);
				const auto v = cur->get(ref);
				if (name != ref)
					cur->data[name] = v;
				cout << v << endl;
			}
		}
	}
	delete root;
	return 0;
}