#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>
#include <tuple>
#include <cstdlib>
#include <functional>
#include <random>
#define float ILikeFloat

typedef long double float;

using namespace std;

const float eps = 1e-9;

struct Point {
    float x, y;
};

struct Line {
    float a, b, c;

    Line() {
    }

    Line(Point p1, Point p2) :
        a(p2.y - p1.y), b(p1.x - p2.x), c(-(a * p1.x + b * p1.y)) {
    }
};

inline bool operator <(Point a, Point b) {
    return make_pair(a.x, a.y) < make_pair(b.x, b.y);
}

inline bool operator >(Point a, Point b) {
    return make_pair(a.x, a.y) > make_pair(b.x, b.y);
}

inline int ufo(Line a, Line b) {
    if (abs(a.a * b.b - a.b * b.a) < eps) {
        return 0;
    }
    if (abs(a.a) < eps) {
        return -1;
    }
    if (abs(b.a) < eps) {
        return +1;
    }
    if (abs(a.b) < eps) {
        return -1;
    }
    if (abs(b.b) < eps) {
        return +1;
    }
    if (a.a * b.b - a.b * b.a < 0) {
        return -1;
    } else {
        return +1;
    }
}

inline bool operator <(Line a, Line b) {
    return ufo(a, b) < 0;
}

inline bool operator ==(Line a, Line b) {
    return ufo(a, b) == 0;
}

struct LineInfo {
    Line ln;
    int pos;
    int who;

    inline auto toTuple() {
        return make_tuple(ln, pos, who);
    }
};

inline bool operator <(LineInfo a, LineInfo b) {
    return a.toTuple() < b.toTuple();
}

int main() {
    //freopen("input.txt", "r", stdin);

    mt19937_64 rnd(42);

    ios_base::sync_with_stdio(false);
    int n; cin >> n;
    vector<Point> a(n);
    for (int i = 0; i < n; i++) {
        cin >> a[i].x >> a[i].y;
    }
    int m; cin >> m;
    vector<Point> b(m);
    for (int i = 0; i < m; i++) {
        cin >> b[i].x >> b[i].y;
    }

    vector<LineInfo> theLines;
    for (int i = 0; i < n; i++) {
        int j = (i+1) % n;
        theLines.push_back({Line(min(a[i], a[j]), max(a[i], a[j])), i, 0});
    }
    for (int i = 0; i < m; i++) {
        int j = (i+1) % m;
        theLines.push_back({Line(min(b[i], b[j]), max(b[i], b[j])), i, 1});
    }
    sort(theLines.begin(), theLines.end());

    auto checkLines = [&](int beg0, int beg1, Line ln0, Line ln1) -> bool {
        int end0 = (beg0 + 1) % n;
        int end1 = (beg1 + 1) % m;
        Point aBeg = a[beg0], aEnd = a[end0];
        Point bBeg = b[beg1], bEnd = b[end1];

        function<float(Point)> get;
        if (aBeg.x == aEnd.x) {
            get = [&](Point p) -> float {
                return p.y;
            };
        } else {
            get = [&](Point p) -> float {
                return p.x;
            };
        }

        auto lessThan = [&](float a, float b) -> bool {
            return a - b < -eps;
        };

        auto lessEqThan = [&](float a, float b) -> bool {
            return a - b < eps;
        };

        float ab = get(aBeg), ae = get(aEnd);
        float bb = get(bBeg), be = get(bEnd);

        if (lessThan(ae, ab)) {
            swap(ab, ae);
        }
        if (lessThan(be, bb)) {
            swap(bb, be);
        }

        if (lessEqThan(ae, bb) || lessEqThan(be, ab)) {
            return false;
        }

        int mid0 = rnd() % n;
        while (mid0 == beg0 || mid0 == end0) {
            mid0 = rnd() % n;
        }

        int mid1 = rnd() % m;
        while (mid1 == beg1 || mid1 == end1) {
            mid1 = rnd() % m;
        }

        auto liesBetween = [&](Point p) -> bool {
            float newC = -(ln0.a * p.x + ln0.b * p.y);
            float lC = -(ln0.a * aBeg.x + ln0.b * aBeg.y);
            float rC = -(ln0.a * bBeg.x + ln0.b * bBeg.y);
            if (lessThan(rC, lC)) {
                swap(lC, rC);
            }
            return lessThan(lC, newC) && lessThan(newC, rC);
        };

        return !liesBetween(a[mid0]) && !liesBetween(b[mid1]);
    };

    int lnSz = (int)theLines.size();
    for (int i = 0; i < lnSz; ) {
        int p = i;
        while (i < lnSz && theLines[i].ln == theLines[p].ln) {
            i++;
        }

        for (int j = p; j < i; j++) {
            for (int k = p; k < i; k++) {
                if (theLines[j].who == 0 && theLines[k].who == 1) {
                    if (checkLines(theLines[j].pos, theLines[k].pos, theLines[j].ln, theLines[k].ln)) {
                        cout << "YES" << endl;
                        cout << theLines[j].pos + 1 << " " << theLines[k].pos + 1 << endl;
                        return 0;
                    }
                }
            }
        }
    }

    cout << "NO" << endl;
    return 0;
}
