#include <iostream>
#include <vector>
#include <map>

using namespace std;

const int sparseDepth = 20;

class SparseTable {
private:
    int n;
    vector< vector<int> > a;
    vector<int> lg;
public:
    inline int64_t rmq(int l, int r) {
        int w = lg[r - l + 1];
        return max(a[w][l], a[w][r - (1 << w) + 1]);
    }

    SparseTable(vector<int> v) :
        n(v.size()), a(sparseDepth, vector<int>(n)), lg(n+1) {
        lg[1] = 0;
        for (int i = 2; i <= n; i++) {
            lg[i] = lg[i/2] + 1;
        }
        for (int i = 0; i < n; i++) {
            a[0][i] = v[i];
        }
        for (int i = 1; i < sparseDepth; i++) {
            for (int j = 0; j <= n - (1 << i); j++) {
                a[i][j] = max(a[i-1][j], a[i-1][j + (1 << (i-1))]);
            }
        }
    }
};

const int64_t mod = (int64_t)1e9 + 7;

inline int64_t fH(int64_t sz) {
    return (sz+1) * (sz+2) / 2 % mod;
}

inline void calcForHoles(vector<int64_t> holes, int64_t &pairs, int64_t &fours) {
    int sz = (int)holes.size() - 1;

    /*cout << "!!!!!" << endl;
    for (int i = 0; i <= sz; i++) {
        cout << holes[i] << " ";
    }
    cout << endl;*/

    vector<int64_t> pref1(sz), pref2(sz), suf1(sz), suf2(sz);
    for (int64_t i = 0, pre = holes[0]+1; i < sz; i++, pre += holes[i] + 1) {
        pref1[i] = pre % mod;
        pref2[i] = (pre * holes[i+1] + pre) % mod;
    }
    for (int64_t i = sz-1, pre = holes[sz]+1; i >= 0; pre += holes[i] + 1, i--) {
        suf1[i] = pre % mod;
        suf2[i] = (pre * holes[i] + pre) % mod;
    }

    /*for (int i = 0; i < sz; i++) {
        cout << pref1[i] << " ";
    }
    cout << endl;
    for (int i = 0; i < sz; i++) {
        cout << pref2[i] << " ";
    }
    cout << endl;
    for (int i = 0; i < sz; i++) {
        cout << suf1[i] << " ";
    }
    cout << endl;
    for (int i = 0; i < sz; i++) {
        cout << suf2[i] << " ";
    }
    cout << endl;*/

    pairs = 0;
    fours = 0;
    for (int64_t i = 0; i < sz; pairs += pref2[i], pairs %= mod, i++) {
         if (i == sz-1) {
            continue;
         }
         fours += pairs * suf2[i+1];
         fours %= mod;
         fours += pref1[i] * suf1[i+1] % mod * fH(holes[i+1]) % mod;
         fours %= mod;
    }

    //cout << " res :: " << pairs << " " << fours << endl;
}

int main() {
    //freopen("input.txt", "r", stdin);
    ios_base::sync_with_stdio(false);

    int n; cin >> n;
    vector<int> v(n);
    for (int i = 0; i < n; i++) {
        cin >> v[i];
    }

    map<int64_t, int> kompr;
    for (int i = 0; i < n; i++) {
        kompr[v[i]] = 42;
    }
    int komptr = 0;
    for (auto &it : kompr) {
        it.second = komptr++;
    }
    for (int i = 0; i < n; i++) {
        v[i] = kompr[v[i]];
    }
    int k = komptr;

    vector< vector<int> > meet(k);
    for (int i = 0; i < n; i++) {
        meet[v[i]].push_back(i);
    }

    vector<int> lmeq(n), rmeq(n);

    SparseTable st(v);

    for (int i = 0; i < n; i++) {
        int l = -1, r = i-1;
        while (l != r) {
            int m = (l + r + 21) / 2 - 10;
            if (st.rmq(m, i-1) >= v[i]) {
                l = m;
            } else {
                r = m-1;
            }
        }
        lmeq[i] = l;
    }

    for (int i = 0; i < n; i++) {
        int l = i+1, r = n;
        while (l != r) {
            int m = (l + r) / 2;
            if (st.rmq(i+1, m) >= v[i]) {
                r = m;
            } else {
                l = m+1;
            }
        }
        rmeq[i] = l;
    }

    int64_t ans = 0;

    for (int md = 0; md < k; md++) {
        int64_t preAns = 0;
        vector<int> &mt = meet[md];
        for (int i = 0; i < (int)mt.size(); ) {
            int p = i;
            while (i+1 < (int)mt.size() && rmeq[mt[i]] < n && v[rmeq[mt[i]]] == md) {
                i++;
            }
            i++;

            //cout << "md " << md << " :: " << p << " - " << i << endl;
            //cout << "!!! " << mt[p] << " " << mt[i-1] << " " << rmeq[mt[i-1]] << endl;

            vector<int64_t> holes(i - p + 1);
            holes[0] = mt[p] - lmeq[mt[p]] - 1;
            for (int j = p; j < i; j++) {
                holes[j - p + 1] = rmeq[mt[j]] - mt[j] - 1;
            }
            int64_t pairs, fours;
            calcForHoles(holes, pairs, fours);
            pairs %= mod;
            fours %= mod;
            ans += fours;
            ans %= mod;
            ans += preAns * pairs;
            ans %= mod;
            preAns += pairs;
            preAns %= mod;

            //cout << "preAns! " << preAns << endl;
        }
        //cout << "end. ans = " << ans << endl;
    }

    cout << ans << endl;
    return 0;
}
