#include <iostream>
#include <vector>
#include <queue>
#include <algorithm>
#include <climits>
#include <tuple>

using namespace std;

const int VERTEX_INFECT = 0;
const int EDGE_APPEAR = 1;
const int EDGE_DISAPPEAR = 2;

struct Edge {
    int a, b, c;
};

struct Event {
    int64_t time;
    int kind;
    int who;

    inline auto toTuple() {
        return make_tuple(time, kind, who);
    }
};

inline bool operator<(Event a, Event b) {
    return a.toTuple() < b.toTuple();
}

int main() {
    ios_base::sync_with_stdio(false);

    int n; cin >> n;
    vector< vector< pair<int, int> > > g(n);
    vector<Edge> edges;
    for (int i = 1; i < n; i++) {
        int a, b, c; cin >> a >> b >> c; a--; b--; c *= 2;
        g[a].emplace_back(b, c);
        g[b].emplace_back(a, c);
        edges.push_back({a, b, c});
    }

    vector<int64_t> d(n, LLONG_MAX);
    priority_queue< pair<int64_t, int>, vector<pair<int64_t, int> >, greater< pair<int64_t, int> > > pq;

    int m; cin >> m;
    vector<int> a(m);
    for (int i = 0; i < m; i++) {
        cin >> a[i]; a[i]--;
    }

    for (int i : a) {
        d[i] = 0;
        pq.emplace(d[i], i);
    }

    while (!pq.empty()) {
        int64_t len; int v; tie(len, v) = pq.top(); pq.pop();
        if (d[v] != len) {
            continue;
        }
        for (auto it : g[v]) {
            int to, way; tie(to, way) = it;
            if (d[to] > len + way) {
                d[to] = len + way;
                pq.emplace(d[to], to);
            }
        }
    }

    vector<Event> events;
    for (int i = 0; i < n; i++) {
        events.push_back({d[i], VERTEX_INFECT, i});
    }
    for (Edge edge : edges) {
        if (d[edge.a] > d[edge.b]) {
            swap(edge.a, edge.b);
        }
        if (d[edge.a] + edge.c == d[edge.b]) {
            continue;
        }
        events.push_back({d[edge.b], EDGE_APPEAR, -1});
        events.push_back({(edge.c + d[edge.a] + d[edge.b]) / 2, EDGE_DISAPPEAR, -1});
    }

    sort(events.begin(), events.end());
    reverse(events.begin(), events.end());

    int ans = 0;
    int qur = 0;
    vector<char> infect(n, true);

    for (int i = 0; i < (int)events.size(); ) {
        int p = i;
        while (i < (int)events.size() && events[p].time == events[i].time) {
            Event ev = events[i++];
            if (ev.kind == VERTEX_INFECT) {
                qur++;
                for (auto to : g[ev.who]) {
                    if (!infect[to.first]) {
                        qur--;
                    }
                }
                infect[ev.who] = false;
            } else if (ev.kind == EDGE_APPEAR) {
                qur--;
            } else if (ev.kind == EDGE_DISAPPEAR) {
                qur++;
            }
        }
        ans = max(ans, qur);
    }

    cout << ans << endl;
    return 0;
}
