﻿using System;
using System.Collections.Generic;
using System.Linq;

namespace ConsoleApp1
{
    class Block
    {
        private Dictionary<string, int> locals = new Dictionary<string, int>();
        private Block parent;

        public Block(Block pParent) => parent = pParent;

        public void Run(string[] lines, ref int index)
        {
            while(index < lines.Length)
            {
                if (lines[index].Length == 0)
                {
                    index++;
                    continue;
                }
                if(lines[index][0] == '}')
                {
                    index++;
                    return;
                }
                if(lines[index][0] == '{')
                {
                    index++;
                    Block child = new Block(this);
                    child.Run(lines, ref index);
                }
                else
                {
                    string[] clause = lines[index].Split('=');
                    int value;
                    if (char.IsDigit(clause[1][0]) || clause[1][0] == '-') value = int.Parse(clause[1]);
                    else
                    {
                        value = this[clause[1]];
                        Console.WriteLine(value);
                    }
                    this[clause[0]] = value;
                    index++;
                }
            }
        }

        private int? GetVal(string variable)
        {
            if (locals.ContainsKey(variable)) return locals[variable];
            if (parent == null) return null;
            return parent.GetVal(variable);
        }
            
        public int this[string variable]
        {
            get
            {
                int? result = GetVal(variable);
                if(result == null)
                {
                    locals.Add(variable, 0);
                    return 0;
                }
                return result.Value;
            }
            set
            {
                locals[variable] = value;
            }
        }
    }

    class Program
    {
        static string[] GetLines()
        {
            return Console.In.ReadToEnd().Split('\n').Select(s => s.Trim()).ToArray();
        }

        static void Main(string[] args)
        {
            string[] lines = GetLines();
            Block mainBlock = new Block(null);
            int index = 0;
            mainBlock.Run(lines, ref index);
            //Console.ReadKey();
        }
    }
}
