﻿using System;
using System.Collections.Generic;
using System.Linq;

namespace ConsoleApp1
{
    class Parser
    {
        private string[] tokens;
        private int index = 0;

        public Parser(string input)
        {
            tokens = input.Split(' ', '\n', '=').Where(s => s != "").ToArray();
        }

        public string NextToken()
        {
            return index == tokens.Length ? null : tokens[index++];
        }
    }

    class Block
    {
        private Dictionary<string, int> locals = new Dictionary<string, int>();
        private Block parent;

        public Block(Block pParent) => parent = pParent;

        public void Run(Parser lines)
        {
            string token = lines.NextToken();
            while(token != null)
            {
                if (token[0] == '}') return;
                if(token[0] == '{')
                {
                    Block child = new Block(this);
                    child.Run(lines);
                }
                else
                {
                    string fst = token;
                    string snd = lines.NextToken();
                    int value;
                    if (char.IsDigit(snd[0]) || snd[0] == '-') value = int.Parse(snd);
                    else
                    {
                        value = this[snd];
                        Console.WriteLine(value);
                    }
                    this[fst] = value;
                }
                token = lines.NextToken();
            }
        }

        private int? GetVal(string variable)
        {
            if (locals.ContainsKey(variable)) return locals[variable];
            if (parent == null) return null;
            return parent.GetVal(variable);
        }
            
        public int this[string variable]
        {
            get
            {
                int? result = GetVal(variable);
                if(result == null)
                {
                    locals.Add(variable, 0);
                    return 0;
                }
                return result.Value;
            }
            set
            {
                locals[variable] = value;
            }
        }
    }

    class Program
    {
        static string ReadToEnd() => Console.In.ReadToEnd();

        static void Main(string[] args)
        {
            Parser lines = new Parser(ReadToEnd());
            Block mainBlock = new Block(null);
            int index = 0;
            mainBlock.Run(lines);
            //Console.ReadKey();
        }
    }
}
