#include <map>
#include <set>
#include <cassert>
#include <cstdio>
#include <cstdlib>
#include <queue>

using namespace std;

const int MAXN = 300000;
const int MAXM = 300000;

const int MOD = 998244353;

int sum(int a, int b) {
  return (a + b) % MOD; 
}
int mul(int a, int b) {
  return (a * 1LL * b) % MOD;
}

struct edge {
  int cnt_tree;
  int cnt_part;
};

edge merge_series(const edge& a, const edge& b) {
  return {
    mul(a.cnt_tree, b.cnt_tree),
    sum(mul(a.cnt_tree, b.cnt_part), mul(a.cnt_part, b.cnt_tree))
  };
}

edge merge_parallel(const edge& a, const edge& b) {
  return {
    sum(mul(a.cnt_tree, b.cnt_part), mul(a.cnt_part, b.cnt_tree)),
    mul(a.cnt_part, b.cnt_part)
  };
}

map<int, edge> es[MAXN];

void adde(map<int, edge>& x, int to, const edge& e) {
  auto it = x.find(to);
  if (it == x.end()) {
    x[to] = e;
  } else {
    it->second = merge_parallel(it->second, e);
  }
}

int main() {
  int n, m;
  scanf("%d%d", &n, &m);
  for (int i = 0; i < m; i++) {
    int a, b;
    scanf("%d%d", &a, &b);
    --a; --b;
    adde(es[a], b, {1, 1});
    adde(es[b], a, {1, 1});
  }

  queue<int> q;
  vector<bool> inq(n);
  for (int i = 1; i < n - 1; i++) {
    if (es[i].size() == 2) {
      q.push(i);
      inq[i] = true;
    }
  }
  while (!q.empty()) {
    int x = q.front();
    q.pop();
    assert(es[x].size() == 2);
    int u = es[x].begin()->first;
    int v = es[x].rbegin()->first;

    edge res = merge_series(es[x].begin()->second, es[x].rbegin()->second);

    es[u].erase(x);
    es[v].erase(x);

    adde(es[u], v, res);
    adde(es[v], u, res);

    if (u != 0 && u != n - 1 && es[u].size() == 2 && !inq[u]) {
      q.push(u);
      inq[u] = true;
    }
    if (v != 0 && v != n - 1 && es[v].size() == 2 && !inq[v]) {
      q.push(v);
      inq[v] = true;
    }
  }
  assert(es[0].size() == 1);
  assert(es[n - 1].size() == 1);
  assert(es[0].begin()->first == n - 1);
  assert(es[n - 1].begin()->first == 0);
  printf("%d\n", es[0][n-1].cnt_tree);
  return 0;
}
